@@ -6,7 +6,7 @@
     security via Flask-Login, Flask-Principal, Flask-WTF, and passlib.
 
     :copyright: (c) 2012-2019 by Matt Wright.
-    :copyright: (c) 2019-2022 by J. Christopher Wagner.
+    :copyright: (c) 2019-2023 by J. Christopher Wagner.
     :license: MIT, see LICENSE for more details.
 """
 
@@ -18,6 +18,7 @@ from .core import (
     UserMixin,
     WebAuthnMixin,
     AnonymousUser,
+    FormInfo,
     current_user,
 )
 from .datastore import (
@@ -43,6 +44,7 @@ from .decorators import (
     unauth_csrf,
 )
 from .forms import (
+    Form,
     ChangePasswordForm,
     ForgotPasswordForm,
     LoginForm,
@@ -50,8 +52,6 @@ from .forms import (
     ResetPasswordForm,
     PasswordlessLoginForm,
     ConfirmRegisterForm,
-    MfRecoveryForm,
-    MfRecoveryCodesForm,
     SendConfirmationForm,
     TwoFactorRescueForm,
     TwoFactorSetupForm,
@@ -60,8 +60,14 @@ from .forms import (
     unique_identity_attribute,
 )
 from .mail_util import MailUtil
+from .oauth_glue import OAuthGlue
 from .password_util import PasswordUtil
 from .phone_util import PhoneUtil
+from .recovery_codes import (
+    MfRecoveryCodesUtil,
+    MfRecoveryForm,
+    MfRecoveryCodesForm,
+)
 from .signals import (
     confirm_instructions_sent,
     login_instructions_sent,
@@ -75,6 +81,7 @@ from .signals import (
     user_authenticated,
     user_confirmed,
     user_registered,
+    user_not_registered,
     us_security_token_sent,
     us_profile_changed,
     wan_deleted,
@@ -127,4 +134,4 @@ from .webauthn import (
 )
 from .webauthn_util import WebauthnUtil
 
-__version__ = "5.0.2"
+__version__ = "5.1.1"
