@@ -141,6 +141,14 @@ def app(request: pytest.FixtureRequest) -> "SecurityFixture":
     if webauthn_test is not None:
         pytest.importorskip("webauthn")
 
+    oauthlib_test = marker_getter("oauth")
+    if oauthlib_test is not None:
+        pytest.importorskip("authlib")
+
+    mfa_test = marker_getter("two_factor") or marker_getter("unified_signin")
+    if mfa_test is not None:
+        pytest.importorskip("cryptography")
+
     # Override config settings as requested for this test
     settings = marker_getter("settings")
     if settings is not None:
@@ -275,12 +283,9 @@ def app(request: pytest.FixtureRequest) -> "SecurityFixture":
     def revert_forms():
         # Some forms/tests have dynamic fields - be sure to revert them.
         if hasattr(app, "security"):
-            if hasattr(app.security.login_form, "username"):
-                del app.security.login_form.username
-            if hasattr(app.security.register_form, "username"):
-                del app.security.register_form.username
-            if hasattr(app.security.confirm_register_form, "username"):
-                del app.security.confirm_register_form.username
+            for form_name in ["login_form", "register_form", "confirm_register_form"]:
+                if hasattr(app.security.forms[form_name].cls, "username"):
+                    del app.security.forms[form_name].cls.username
 
     request.addfinalizer(revert_forms)
     return app
@@ -410,6 +415,10 @@ def sqlalchemy_setup(request, app, tmpdir, realdburl):
     else:
         app.config["SQLALCHEMY_DATABASE_URI"] = "sqlite:///:memory:"
 
+    # In Flask-SQLAlchemy >= 3.0.0 queries are no longer logged automatically,
+    # even in debug or testing mode.
+    app.config["SQLALCHEMY_RECORD_QUERIES"] = True
+
     db = SQLAlchemy(app)
 
     fsqla.FsModels.set_db_info(db)
@@ -433,8 +442,9 @@ def sqlalchemy_setup(request, app, tmpdir, realdburl):
 
     def tear_down():
         if realdburl:
-            db.drop_all()
-            _teardown_realdb(db_info)
+            with app.app_context():
+                db.drop_all()
+                _teardown_realdb(db_info)
 
     request.addfinalizer(tear_down)
 
@@ -452,8 +462,14 @@ def sqlalchemy_session_setup(request, app, tmpdir, realdburl):
     """
     pytest.importorskip("sqlalchemy")
     from sqlalchemy import create_engine
-    from sqlalchemy.orm import scoped_session, sessionmaker, relationship, backref
-    from sqlalchemy.ext.declarative import declarative_base, declared_attr
+    from sqlalchemy.orm import (
+        scoped_session,
+        sessionmaker,
+        relationship,
+        backref,
+        declarative_base,
+    )
+    from sqlalchemy.ext.declarative import declared_attr
     from sqlalchemy.ext.mutable import MutableList
     from sqlalchemy.sql import func
     from sqlalchemy import (
@@ -561,7 +577,9 @@ def sqlalchemy_session_setup(request, app, tmpdir, realdburl):
         active = Column(Boolean())
         confirmed_at = Column(DateTime())
         roles = relationship(
-            "Role", secondary="roles_users", backref=backref("users", lazy="dynamic")
+            "Role",
+            secondary="roles_users",
+            backref=backref("users", lazy="dynamic", cascade_backrefs=False),
         )
         update_datetime = Column(
             DateTime,
@@ -734,7 +752,6 @@ def pony_datastore(request, app, tmpdir, realdburl):
 
 
 def pony_setup(request, app, tmpdir, realdburl):
-
     pytest.importorskip("pony")
     from pony.orm import Database, Optional, Required, Set
     from pony.orm.core import SetInstance
